@@ -31,8 +31,12 @@ Revision History
 #include "aarch64/efilibplat.h"
 #elif defined (_M_ARM) || defined(__arm__)
 #include "arm/efilibplat.h"
-#elif defined (_M_MIPS64) || defined(__mips64__)
+#elif defined (_M_MIPS64) || defined(__mips64__) || defined(__mips64)
 #include "mips64el/efilibplat.h"
+#elif defined (__riscv) && __riscv_xlen == 64
+#include "riscv64/efilibplat.h"
+#elif defined (__loongarch64)
+#include "loongarch64/efilibplat.h"
 #endif
 #include "efilink.h"
 #include "efirtlib.h"
@@ -57,6 +61,8 @@ extern EFI_GUID gEfiDevicePathToTextProtocolGuid;
 #define DevicePathToTextProtocol gEfiDevicePathToTextProtocolGuid
 extern EFI_GUID gEfiDevicePathFromTextProtocolGuid;
 #define DevicePathFromTextProtocol gEfiDevicePathFromTextProtocolGuid
+extern EFI_GUID gEfiDevicePathUtilitiesProtocolGuid;
+#define DevicePathUtilitiesProtocol gEfiDevicePathUtilitiesProtocolGuid
 extern EFI_GUID gEfiLoadedImageProtocolGuid;
 #define LoadedImageProtocol gEfiLoadedImageProtocolGuid
 extern EFI_GUID gEfiSimpleTextInProtocolGuid;
@@ -151,6 +157,7 @@ extern EFI_GUID AcpiTableGuid;
 extern EFI_GUID SMBIOSTableGuid;
 extern EFI_GUID SMBIOS3TableGuid;
 extern EFI_GUID SalSystemTableGuid;
+extern EFI_GUID EfiDtbTableGuid;
 
 extern EFI_GUID SimplePointerProtocol;
 extern EFI_GUID AbsolutePointerProtocol;
@@ -160,6 +167,10 @@ extern EFI_GUID gEfiDebugSupportProtocolGuid;
 
 extern EFI_GUID SimpleTextInputExProtocol;
 
+extern EFI_GUID ShellProtocolGuid;
+extern EFI_GUID ShellParametersProtocolGuid;
+extern EFI_GUID ShellDynamicCommandProtocolGuid;
+
 //
 // EFI Variable strings
 //
